#!/usr/bin/env python3
#
# SPDX-License-Identifier: MIT
#
# Copyright (C) 2023 Ying-Chun Liu (PaulLiu) <paulliu@debian.org>
#

import re
import sys
import argparse

if __name__ == '__main__':

    parser = argparse.ArgumentParser()
    parser.add_argument("dictfile",
                        help="Dictionary file.")

    args = parser.parse_args()
    
    dictfile = args.dictfile
    
    main_re = re.compile(r"([^ ]+)[ ]([^ ]+)[ ]([\[].*[\]])[ ][/](.*)[/]")
    fi = open(dictfile, "r")

    dictData = {}

    while (True):
        line = fi.readline()
        if not line:
            break
        line = line.strip()
        if (len(line) > 0 and line[0] == '#'):
                continue
        match = main_re.search(line)
        if (match is None):
            print("Error", file=sys.stderr)
            sys.exit(1)

        explain = match.group(4)
        explains = explain.split("/")

        if (match.group(1) in dictData):
            dictData[match.group(1)].append(match.group(3))
            dictData[match.group(1)].extend(explains)
        else:
            dictData[match.group(1)] = [ match.group(3) ]
            dictData[match.group(1)].extend(explains)
        if (match.group(1) != match.group(2)):
            if (match.group(2) in dictData):
                dictData[match.group(2)].append(match.group(3))
                dictData[match.group(2)].extend(explains)
            else:
                dictData[match.group(2)] = [ match.group(3) ]
                dictData[match.group(2)].extend(explains)

    print("This work is licensed under a Creative Commons Attribution-ShareAlike 4.0 International License (click https://creativecommons.org/licenses/by-sa/4.0/ for detailed information)")
    print("It more or less means that you are allowed to use this data for both non-commercial and commercial purposes provided that you: mention where you got the data from (attribution) and that in case you improve / add to the data you will share these changes under the same license (share alike).")

    for key in dictData.keys():
        print(key)
        for i in range(len(dictData[key])):
            s = dictData[key][i]
            print(" ", end="")
            print(s)
